Data documentation compiled by Great Expectations

Documentation autogenerated using Great Expectations.
This is a beta feature! Expect changes in API, behavior, and design.

### Age

- value types must belong to this set: DOUBLE_PRECISION DoubleType FLOAT FloatType NUMERIC float.
- may have any number of unique values.
- may have any percentage of unique values.
- values must never be null.
- Couldn't render expectation of type expect_column_min_to_be_between
- Couldn't render expectation of type expect_column_max_to_be_between
- Couldn't render expectation of type expect_column_mean_to_be_between
- Couldn't render expectation of type expect_column_median_to_be_between
- Couldn't render expectation of type expect_column_quantile_values_to_be_between
- Couldn't render expectation of type expect_column_kl_divergence_to_be_less_than

### Name

- value types must belong to this set: CHAR StringType TEXT VARCHAR str string.
- may have any number of unique values.
- may have any percentage of unique values.
- values must never be null.

### PClass

- value types must belong to this set: CHAR StringType TEXT VARCHAR str string.
- may have any number of unique values.
- may have any percentage of unique values.
- values must never be null.
- values must not match this regular expression: ^\s+|\s+$.
- values must belong to a set, but that set is not specified.

### Sex

- value types must belong to this set: CHAR StringType TEXT VARCHAR str string.
- may have any number of unique values.
- may have any percentage of unique values.
- values must never be null.
- values must not match this regular expression: ^\s+|\s+$.
- values must belong to a set, but that set is not specified.

### SexCode

- value types must belong to this set: BIGINT INTEGER IntegerType LongType SMALLINT int.
- may have any number of unique values.
- may have any percentage of unique values.
- values must never be null.
- values must belong to a set, but that set is not specified.

### Survived

- value types must belong to this set: BIGINT INTEGER IntegerType LongType SMALLINT int.
- may have any number of unique values.
- may have any percentage of unique values.
- values must never be null.
- values must belong to a set, but that set is not specified.

### Unnamed: 0

- value types must belong to this set: BIGINT INTEGER IntegerType LongType SMALLINT int.
- may have any number of unique values.
- may have any percentage of unique values.
- values must never be null.
- values must be unique.

### None

- Must have more than 0 rows.
- This table should have a list of columns in a specific order, but that order is not specified.